Crate sea_orm_spanner

Crate sea_orm_spanner 

Re-exports

pub use json_support::SpannerJson;
pub use json_support::SpannerOptionalJson;
pub use uuid_support::SpannerUuid;
pub use sea_orm::Set;
pub use sea_orm::Unchanged;
pub use array_support::*;

Modules

array_support
async_trait
githubcrates-iodocs-rs
chrono_support
json_support
uuid_support

Structs

ChronoDate
ISO 8601 calendar date without timezone. Allows for every proleptic Gregorian date from Jan 1, 262145 BCE to Dec 31, 262143 CE. Also supports the conversion from ISO 8601 ordinal and week date.
ChronoDateTime
ISO 8601 combined date and time without timezone.
ChronoTime
ISO 8601 time without timezone. Allows for the nanosecond precision and optional leap second representation.
ChronoUnixTimestamp
A DataTime mapped to i64 in database
ChronoUnixTimestampMillis
A DataTime mapped to i64 in database, but in milliseconds
ClientConfig
ClientConfig has configurations for the client.
ColumnDef
Defines a Column for an Entity
ColumnFromStrErr
Error during impl FromStr for Entity::Column
CreateOptions
Options for creating Spanner instance and database
DatabaseConnection
Handle a database connection depending on the backend enabled by the feature flags. This creates a connection pool internally (for SQLx connections), and so is cheap to clone.
DatabasePath
Parsed components of a Spanner database path
Date
ISO 8601 calendar date without timezone. Allows for every proleptic Gregorian date from Jan 1, 262145 BCE to Dec 31, 262143 CE. Also supports the conversion from ISO 8601 ordinal and week date.
DateTime
ISO 8601 combined date and time without timezone.
Decimal
Decimal represents a 128 bit representation of a fixed-precision decimal number. The finite set of values of type Decimal are of the form m / 10e, where m is an integer such that -296 < m < 296, and e is an integer between 0 and 28 inclusive.
DynIden
A prepared (quoted) identifier string.
InstanceConfig
Configuration for Spanner instance creation
QueryResult
Defines the result of a query operation on a Model
RelationDef
Defines a relationship
SeaRc
A legacy namespace for compatibility.
Select
Defines a structure to perform select operations
SpannerDatabase
SpannerQueryBuilder
TextUuid
Newtype making sure that UUIDs will be stored as TEXT columns, instead of BLOB (which is the default). Advantages:
Time
ISO 8601 time without timezone. Allows for the nanosecond precision and optional leap second representation.
Uuid
A Universally Unique Identifier (UUID).

Enums

ColumnType
All column types
ConnAcquireErr
Connection Acquire error
DatabaseDialect
Database dialect for Spanner
DbErr
An error from unsuccessful database operations
Expr
An arbitrary, dynamically-typed SQL expression.
HasMany
HasManyModel
Container for 1-N or M-N related Models
HasOne
HasOneModel
Container for belongs_to or has_one relation
Json
Represents any valid JSON value.
RuntimeErr
Runtime error
SpannerDbErr
SqlErr
An error from unsuccessful SQL query
StringLen
Length for var-char/binary; default to 255 in MySQL if length is not specified
TryGetError
An error from trying to get a row from a Model
Value
Value variants

Traits

ActiveEnum
A Rust representation of enum defined in database.
ActiveModelBehavior
A Trait for overriding the ActiveModel behavior
ActiveModelTrait
ActiveModel is a type for constructing INSERT and UPDATE statements for a particular table.
ColumnTrait
API for working with a Column. Mostly a wrapper of the identically named methods in sea_query::Expr
ColumnTypeTrait
SeaORM’s utility methods that act on ColumnType
ConnectionTrait
The generic API for a database connection that can perform query or execute statements. It abstracts database connection and transaction
CursorTrait
A trait for any type that can be turn into a cursor
EntityName
A Trait for mapping an Entity to a database table
EntityTrait
An abstract base class for defining Entities.
Iden
Identifier
IdenStatic
Ensure the identifier for an Entity can be converted to a static str
IntoActiveModel
A Trait for any type that can be converted into an ActiveModel, can be derived using DeriveIntoActiveModel.
Linked
A Trait for links between Entities
LoaderTrait
This trait implements the Data Loader API
ModelTrait
The interface for Model, implemented by data structs
PaginatorTrait
A Trait for any type that can paginate results
PrimaryKeyArity
How many columns this Primary Key comprises
PrimaryKeyToColumn
Trait to map a Primary Key to a column
PrimaryKeyTrait
A Trait for to be used to define a Primary Key.
QueryFilter
Perform a FILTER opertation on a statement
QueryOrder
Performs ORDER BY operations
QuerySelect
Abstract API for performing queries
Related
A trait to relate two Entities for them to be joined in queries
RelatedSelfVia
A trait to relate an Entity to itself through a junction table
RelationTrait
Defines the relations of an Entity
SelectExt
Helper trait for selectors with convenient methods

Functions

ensure_database
ensure_instance
ensure_tls
Install the rustls crypto provider for GCP TLS connections.

Type Aliases

ChronoDateTimeLocal
Date time represented in local time
ChronoDateTimeUtc
Date time represented in UTC
ChronoDateTimeWithTimeZone
Date time with fixed offset
ChronoUtc
The UTC type from chrono
DateTimeLocal
Date time represented in local time
DateTimeUtc
Date time represented in UTC
DateTimeWithTimeZone
Date time with fixed offset
DbConn
The same as a DatabaseConnection
ForeignKeyAction
Action to perform on a foreign key whenever there are changes to an ActiveModel
RcOrArc
A reference counted pointer: either Rc or Arc, depending on the feature flags.

Derive Macros

EnumIter
Creates a new type that iterates of the variants of an enum.