HasManyModel

Enum HasManyModel 

pub enum HasManyModel<E>
where E: EntityTrait,
{ NotSet, Replace(Vec<<E as EntityTrait>::ActiveModelEx>), Append(Vec<<E as EntityTrait>::ActiveModelEx>), }
Container for 1-N or M-N related Models

Variants



NotSet

Unspecified value, do nothing



Replace(Vec<<E as EntityTrait>::ActiveModelEx>)

Replace all items with this value set; delete leftovers



Append(Vec<<E as EntityTrait>::ActiveModelEx>)

Add new items to this has many relation; do not delete

Implementations

Source

impl<E> HasManyModel<E>
where E: EntityTrait,

pub fn take(&mut self) -> HasManyModel<E>

Take ownership of the models, leaving NotSet in place

pub fn as_slice(&self) -> &[<E as EntityTrait>::ActiveModelEx]

Borrow models as slice

pub fn as_mut_vec(&mut self) -> &mut Vec<<E as EntityTrait>::ActiveModelEx>

Get a mutable vec. If self is NotSet, convert to append.

pub fn into_vec(self) -> Vec<<E as EntityTrait>::ActiveModelEx>

Consume self as vector

pub fn empty_holder(&self) -> HasManyModel<E>

Returns an empty container of self

pub fn push<AM>(&mut self, model: AM) -> &mut HasManyModel<E>
where AM: Into<<E as EntityTrait>::ActiveModelEx>,

Push an item to self

pub fn append<AM>(&mut self, model: AM) -> &mut HasManyModel<E>
where AM: Into<<E as EntityTrait>::ActiveModelEx>,

Push an item to self, but convert Replace to Append

pub fn replace_all<I>(&mut self, models: I) -> &mut HasManyModel<E>
where I: IntoIterator<Item = <E as EntityTrait>::ActiveModelEx>,

Replace all items in this set

pub fn convert_to_append(&mut self) -> &mut HasManyModel<E>

Convert self to Append, if set

pub fn not_set(&mut self)

Reset self to NotSet

pub fn is_replace(&self) -> bool

If self is Replace

pub fn is_append(&self) -> bool

If self is Append

pub fn is_changed(&self) -> bool

Return true if self is Replace or any containing model is changed

pub fn find(&self, model: &<E as EntityTrait>::Model) -> bool

Find within the models by primary key, return true if found

pub fn try_into_model(self) -> Result<HasMany<E>, DbErr>

Convert this back to a ModelEx container